smartcard.sw.SWExceptions.SWException

# ``smartcard`.`sw`.`SWExceptions`.`SWException``

exception documentation

`class SWException(Exception):`

Known subclasses: `smartcard.sw.SWExceptions.CheckingErrorException`, `smartcard.sw.SWExceptions.ExecutionErrorException`, `smartcard.sw.SWExceptions.SecurityRelatedException`, `smartcard.sw.SWExceptions.WarningProcessingException`

View In Hierarchy

Base class for status word exceptions.

Status word exceptions are generated when errors and warnings are detected in the sw1 and sw2 bytes of the response apdu.

Method | `__init__` | Undocumented
Method | `__str__` | Undocumented
Instance Variable | `data` | response apdu sw1
Instance Variable | `message` | response apdu data
Instance Variable | `sw1` | response apdu sw2
Instance Variable | `sw2` | Undocumented

def __init__(self, data, sw1, sw2, message=''):
overridden in `smartcard.sw.SWExceptions.CheckingErrorException`, `smartcard.sw.SWExceptions.ExecutionErrorException`, `smartcard.sw.SWExceptions.SecurityRelatedException`, `smartcard.sw.SWExceptions.WarningProcessingException`

Undocumented

def __str__(self):

Undocumented

data =

response apdu sw1

message =

response apdu data

sw1 =

response apdu sw2

sw2 =

Undocumented